package systeme;

/**
 * Définit une particule.
 */
public class Particule
{   
    /**
     * Position initiale de la particule.
     */
    private double x ;

    /**
     * Vitesse initiale de la particule.
     */
    private double v ;

    /**
     * Masse de la particule.
     */
    private double m ;

    /**
     * Entier correspondant à l'hydrogène pour cette classe.
     */
    public static final int h = 0 ;
    
    /**
     * Entier correspondant au carbone pour cette classe.
     */  
    public static final int c = 1 ;


    /**
     * Constructeur par défaut, en fonction du type de particule.
     * Ne devrait pas être utilisé.
     * Pour un carbone : (0,0).
     * Pour un hydrogène : (10 nm, -1500 m.s-1).
     * @param type_particule type de la particule
     */
    public Particule(int type_particule)
    {
        switch(type_particule)
        {
            case h:
                x = 10.*1E-9 ;
                v = -1500. ;
                m = 1.660538e-27 ;
                break;

            case c:
                x = 0. ;
                v = 0. ;
                m = 12. * 1.660538e-27 ;
                break;
        }
    }

    /**
     * Constructeur par initialisation.
     * @param type_particule type de la particule (h ou c)
     * @param position position de la particule à donner en m
     * @param vitesse vitesse de la particule à donner en m/s
     */
    public Particule(int type_particule, double position, double vitesse)
    {
        switch(type_particule)
        {
            case h:
                x = position ;
                v = vitesse ;
                m = 1.660538e-27;
            break;

            case c:
                x = position ;
                v = vitesse ;
                m = 12. * 1.660538e-27 ;
            break;
        }
    }
    
    /**
     * Retourne la masse de la particule.
     * @return m
     */
    public double getMasse()
    {
        return m ;
    }
    
    /**
     * Retourne la position de la particule.
     * @return x
     */    
    public double getPosition()
    {
        return x ;
    } 
    
    /**
     * Retourne la vitesse de la particule.
     * @return v
     */      
    public double getVitesse()
    {
        return v ;
    } 
    
}

